@@ -206,6 +206,7 @@ pub struct FlatFiles {
     pub preview: usize,
     only_tables: bool,
     table_order: HashMap<String, String>,
+    pub sqlite_path: String,
 }
 
 #[derive(Serialize, Debug)]
@@ -379,6 +380,7 @@ impl FlatFiles {
             preview: 0,
             only_tables: false,
             table_order: HashMap::new(),
+            sqlite_path: "".to_string(),
         };
 
         flat_files.set_csv(csv)?;
@@ -1480,7 +1482,10 @@ impl FlatFiles {
     }
 
     pub fn write_sqlite_db(&mut self) -> Result<()> {
-        let sqlite_dir_path = self.output_path.join("sqlite.db");
+        let mut sqlite_dir_path = self.output_path.join("sqlite.db");
+        if !self.sqlite_path.is_empty() {
+            sqlite_dir_path = PathBuf::from(&self.sqlite_path);
+        }
         let tmp_path = self.output_path.join("tmp");
 
         let mut conn = Connection::open(sqlite_dir_path).context(RusqliteSnafu {})?;
@@ -1822,13 +1827,15 @@ mod tests {
 
     fn test_output(file: &str, output: Vec<&str>, options: Value) {
         let tmp_dir = TempDir::new().unwrap();
+        let mut name = file.split("/").last().unwrap().to_string();
         let output_dir = tmp_dir.path().join("output");
         let output_path = output_dir.to_string_lossy().into_owned();
         let mut flat_files = FlatFiles::new_with_defaults(output_path.clone()).unwrap();
         let mut path = vec![];
 
         if let Some(inline) = options["inline"].as_bool() {
-            flat_files.inline_one_to_one = inline
+            flat_files.inline_one_to_one = inline;
+            name.push_str("-inline")
         }
 
         flat_files.xlsx = true;
@@ -1836,6 +1843,10 @@ mod tests {
 
         if let Some(tables_csv) = options["tables_csv"].as_str() {
             let tables_only = options["tables_only"].as_bool().unwrap();
+            name.push_str("-tablescsv");
+            if tables_only {
+                name.push_str("-tablesonly")
+            }
 
             flat_files
                 .use_tables_csv(tables_csv.to_string(), tables_only)
@@ -1846,6 +1857,8 @@ mod tests {
                 .iter()
                 .map(|item| item.as_str().unwrap().to_string())
                 .collect();
+
+            name.push_str("-withpath")
         }
 
         let result;
@@ -1878,18 +1891,19 @@ mod tests {
         test_files.extend(output);
 
         for test_file in test_files {
+            let new_name = format!("{}-{}", name, test_file);
             if test_file.ends_with(".json") {
                 let value: Value = serde_json::from_reader(
                     File::open(format!("{}/{}", output_path.clone(), test_file)).unwrap(),
                 )
                 .unwrap();
-                insta::assert_yaml_snapshot!(&value);
+                insta::assert_yaml_snapshot!(new_name, &value);
             } else {
                 let file_as_string =
                     read_to_string(format!("{}/{}", output_path.clone(), test_file)).unwrap();
 
                 let output: Vec<_> = file_as_string.lines().collect();
-                insta::assert_yaml_snapshot!(output);
+                insta::assert_yaml_snapshot!(new_name, output);
             }
         }
     }
